@@ -3,7 +3,7 @@ package Mojolicious::Plugin::Web::Auth;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Mojo::Base 'Mojolicious::Plugin';
 
@@ -11,7 +11,11 @@ sub register {
     my ( $self, $app, $args ) = @_;
     my $module = delete $args->{module} or die "Missing mandatory parameter: module";
     my $klass  = join '::', __PACKAGE__, 'Site', $module;
-    Mojo::Loader->load($klass);
+    if ($Mojolicious::VERSION >= 5.81) {
+        Mojo::Loader::load_class($klass);
+    } else {
+        Mojo::Loader->load($klass);
+    }
 
     my $moniker           = $klass->moniker();
     my $authenticate_path = delete $args->{authenticate_path} || "/auth/${moniker}/authenticate";
